@@ -87,8 +87,7 @@ class WeakNetworkConfig(object):
         while True:
             if time.time() - t1 > timeout:
                 raise Exception('get_device_ip:{} timeout:{}'.format(serial, timeout))
-            ret = self._stf.toggleAndroidWifi(serial, "1", wifiname=self._wifi_name, wifipass=self._wifi_password)
-            logger.info("get toggleAndroidWifi response :{}".format(ret))
+            self._stf.toggleAndroidWifi(serial, "1", wifiname=self._wifi_name, wifipass=self._wifi_password)
             ip = self._stf.get_android_device_ip(serial)
             logger.info("get_android_device_ip :{} return ip :{}".format(serial, ip))
             if str(ip).startswith("192.168.0"):
